@@ -12,6 +12,7 @@
 namespace Ui {
     class DeparturesWindow;
 }
+class DeparturesWindow;
 
 class DepartureListModel : public QAbstractListModel {
     Q_OBJECT
@@ -29,6 +30,19 @@ private:
     QList<Departure *> departure_list;
 };
 
+class DepartureListDelegate : public QStyledItemDelegate {
+    Q_OBJECT
+
+public:
+    DepartureListDelegate(DeparturesWindow *parent)
+        : QStyledItemDelegate((QObject*)parent) {departuresWindow = parent;}
+
+    void paint(QPainter *painter, const QStyleOptionViewItem &option,
+               const QModelIndex &index) const;
+    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index);
+    DeparturesWindow* departuresWindow;
+};
+
 class DeparturesWindow : public QMainWindow
 {
     Q_OBJECT
@@ -38,6 +52,9 @@ public:
     ~DeparturesWindow();
 
     void refreshData();
+    DepartureListDelegate* delegate;
+
+    bool portraitMode() {return _portraitMode;}
 
 protected:
     void changeEvent(QEvent *e);
@@ -46,26 +63,17 @@ private:
     Ui::DeparturesWindow *ui;
     QNetworkAccessManager *manager;
     Place place;
-    bool portraitMode;
+    bool _portraitMode;
     DepartureListModel *model;
 
 private slots:
+    void on_refreshButton_clicked();
+    void on_actionRefresh_triggered();
+    void on_actionAddFavorite_triggered();
     void on_actionRoute_to_triggered();
     void on_actionRoute_from_triggered();
     void replyFinished(QNetworkReply* reply);
     void orientationChanged();
 };
 
-class DepartureListDelegate : public QStyledItemDelegate {
-    Q_OBJECT
-
-public:
-    DepartureListDelegate(QObject *parent = 0)
-        : QStyledItemDelegate(parent) {}
-
-    void paint(QPainter *painter, const QStyleOptionViewItem &option,
-               const QModelIndex &index) const;
-    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index);
-};
-
 #endif // DEPARTURES_H
