@@ -2,15 +2,15 @@
 #define TRAFIKANTENWINDOW_H
 
 #include <QMainWindow>
+#include <QTimer>
 #include <qnmeapositioninfosource.h>
 #include <qgeopositioninfosource.h>
 #include <qgeosatelliteinfosource.h>
 #include <qgeopositioninfo.h>
 #include <qgeosatelliteinfo.h>
-#include <qnetworkconfigmanager.h>
-#include <qnetworksession.h>
 using namespace QtMobility;
 class SearchDialog;
+class TravelSearchWindow;
 namespace Ui {
     class TrafikantenWindow;
 }
@@ -31,8 +31,14 @@ private:
     QGeoPositionInfoSource *positionSource;
     bool portraitMode;
     SearchDialog* search;
+    TravelSearchWindow* travelSearch;
+    bool positionSearchPerformed;
+    QTime lastPositionSearch;
+    QTimer updateRequestTimer;
 
 private slots:
+    void on_btnFavorites_clicked();
+    void on_btnRecent_clicked();
     void on_actionAbout_triggered();
     void on_btnRouting_clicked();
     void on_btnNearby_clicked();
